# Pypox

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE)

## Description

Pypox version 2 will replace its current version 1.5.+. although stable, it lacks the flexibility that current python application needed to scale big. we remove FastAPI system from the pypox version 2 for the reason that most of the features that FastAPI brings cant be properly implemented on pypox. that's why we now use pure starlette as a toolkit for implementing routing, middleware, etc.

the main feature that Pypox version 2 will have is its modular system. from convention based lookup, file based routing, (new middleware based routing) for local and global scope. new processor to convert your data into usable parameters when dealing with request and response.

## Features

- File based routing
- Processor based system.
- many more

## Installation

This is under development and will be published soon. stay tuned!

## Usage

We will provide example soon!!!
